Flag Slurper — Flag Slurper 0.4 documentation

# Flag Slurper

Flag slurper is a Red Team utility for Cyber Defense Competitions. It provides Auto PWN functionality, as well as functionality for tracking obtained credentials, files, and most importantly, flags.

- Projects
  - Flags
  - Credentials
- Files
  - Usage
  - Example
- Glossary

Auto PWN

- Overview
  - Requirements
  - Usage
- Post PWN
  - Configuration
  - Plugins
    - SSH Exfil
  - Custom Plugins
  - Loading Custom Plugins

# Indices and tables

- Index
- Module Index
- Search Page